pub struct Context {
pub storage: StorageContext,
pub playback: PlaybackContext,
pub ui: UIContext,
pub processing: ProcessingContext,
pub performance_metrics: PerformanceMetricsContext,
}Fields
storage: StorageContextAll the tracks and playlists that have been loaded into memory from the database. It is also possible to modify this loaded data in order to be up to date with database entries.
playback: PlaybackContextSelected items that are used for currently playing tracks within a playlist, configured shuffle direction and type from autoplay, and the state of progression through the playing track along with volume level.
ui: UIContextWhat’s currently being shown from the perspective of the UI.
processing: ProcessingContextBackground jobs that are actively processing.
performance_metrics: PerformanceMetricsContextPerformance-related metrics data (latency, FPS, etc.).